>>65,66
ありがとうございます。明示的な型宣言は無理で、利用する際に下位1バイトだけを
持ってくるしかないんですね。勉強になりました。以下実行速度です。

$ time { ./65.pl; }
255
real 0m0.133s
user 0m0.030s
sys 0m0.077s

$ time { ./66.pl; }
255
real 0m0.144s
user 0m0.046s
sys 0m0.062s

後学のために、ついでに質問させていただきますが、
$hensuuを大きな配列($hensuu[0xFFFFFF]など)として利用する場合、
メモリ消費を節約しようと考えたら、pack/unpackなどを使い自分でデータを管理した方が早いでしょうか。
是非をお答えいただけたら幸いです。